@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP11::Operation;
 use vars '$VERSION';
-$VERSION = '2.14';
+$VERSION = '2.15';
 
 use base 'XML::Compile::Operation';
 
@@ -18,6 +18,7 @@ use XML::Compile::Util       qw/pack_type unpack_type/;
 use XML::Compile::SOAP::Util qw/:soap11/;
 use XML::Compile::SOAP11::Client;
 use XML::Compile::SOAP11::Server;
+use XML::Compile::SOAP::Extension;
 
 our $VERSION;         # OODoc adds $VERSION to the script
 $VERSION ||= 'undef';
@@ -39,6 +40,8 @@ sub init($)
         for qw/input_def output_def fault_def/;
 
     $self->{style} = $args->{style} || 'document';
+
+    XML::Compile::SOAP::Extension->soap11OperationInit($self);
     $self;
 }
 
@@ -196,10 +199,29 @@ sub style()     {shift->{style}}
 sub version()   { 'SOAP11' }
 sub serverClass { 'XML::Compile::SOAP11::Server' }
 sub clientClass { 'XML::Compile::SOAP11::Client' }
+sub soapAction  {shift->{action}}
 
 #-------------------------------------------
 
 
+sub addHeader($$$)
+{   my ($self, $dir, $label, $elem) = @_;
+    my $defs
+      = $dir eq 'INPUT'  ? 'input_def'
+      : $dir eq 'OUTPUT' ? 'output_def'
+      : $dir eq 'FAULT'  ? 'fault_def'
+      : panic "addHeader $dir";
+
+    my %part = (part => $label, use => 'literal'
+      , parts => [{name => $label, element => $elem}]);
+    push @{$self->{$defs}{header}}, \%part;
+    \%part;
+}
+
+#-------------------------------------------
+
+
+
 sub compileHandler(@)
 {   my ($self, %args) = @_;
 
@@ -235,13 +257,15 @@ sub compileClient(@)
     my @so   = (%{$self->{input_def}},  %{$self->{fault_def}});
     my @ro   = (%{$self->{output_def}}, %{$self->{fault_def}});
 
-    $soap->compileClient
+    my $call = $soap->compileClient
       ( name         => $self->name
       , kind         => $kind
       , encode       => $soap->_sender(@so, %args)
       , decode       => $soap->_receiver(@ro, %args)
       , transport    => $self->compileTransporter(%args)
       );
+
+    XML::Compile::SOAP::Extension->soap11ClientWrapper($self, $call);
 }
 
 
